!define VERSION "2.0.0"

Name "QTagConvert ${VERSION}"

OutFile ".\qtagconvert_setup-${VERSION}.exe"

InstallDir $PROGRAMFILES\QTagConvert

; Request application privileges for Windows Vista
RequestExecutionLevel user

; Registry key to check for directory (so if you install again, it will 
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\QTagConvert" "Install_Dir"

; First is default
LoadLanguageFile "${NSISDIR}\Contrib\Language files\English.nlf"
LoadLanguageFile "${NSISDIR}\Contrib\Language files\Russian.nlf"

LicenseData copying

SetCompressor /SOLID lzma

; Pages

Page license
Page components
Page directory
Page instfiles
UninstPage uninstConfirm
UninstPage instfiles


Section "QTagConvert"

  SectionIn RO
  
  ; Set output path to the installation directory.
  SetOutPath $INSTDIR
  
  ; Put file there
  File "bin\qtagconvert.exe"
  File "bin\qtagconvert_ru.qm"
  File "bin\mingwm10.dll"
  File "bin\libtag.dll"
  File "COPYING"
  
  ; Write the installation path into the registry
  WriteRegStr HKLM SOFTWARE\QTagConvert "Install_Dir" "$INSTDIR"
  
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\QTagConvert" "DisplayName" "QTagConvert"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\QTagConvert" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\QTagConvert" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\QTagConvert" "NoRepair" 1
  WriteUninstaller "uninstall.exe"

  CreateDirectory "$SMPROGRAMS\QTagConvert"
  CreateShortCut "$SMPROGRAMS\QTagConvert\QTagConvert.lnk" "$INSTDIR\qtagconvert.exe" "" "$INSTDIR\qtagconvert.exe" 0
  CreateShortCut "$SMPROGRAMS\QTagConvert\Uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0
  
SectionEnd

; Optional section (can be disabled by the user)
Section "Qt4 library"
  File "bin\QtCore4.dll"
  File "bin\QtGui4.dll"
SectionEnd

Section "Desktop Shortcut"
  CreateShortCut "$DESKTOP\QTagConvert.lnk" "$INSTDIR\qtagconvert.exe" "" "$INSTDIR\qtagconvert.exe" 0
SectionEnd

Section /o "Sources"
  File "..\qtagconvert-${VERSION}.tar.gz"
SectionEnd

Section "Uninstall"
  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\QTagConvert"
  DeleteRegKey HKLM SOFTWARE\QTagConvert

  ; Remove files and uninstaller
  Delete $INSTDIR\uninstall.exe
  Delete "$INSTDIR\*.*"

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\QTagConvert\*.*"

  ; Remove directories used
  RMDir "$SMPROGRAMS\QTagConvert"
  RMDir "$INSTDIR"
SectionEnd

;--------------------------------

Function .onInit

	;Language selection dialog

	Push ""
	Push ${LANG_ENGLISH}
	Push English
	Push ${LANG_RUSSIAN}
	Push Russian
	Push A ; A means auto count languages
	       ; for the auto count to work the first empty push (Push "") must remain
	LangDLL::LangDialog "Installer Language" "Please select the language of the installer"

	Pop $LANGUAGE
	StrCmp $LANGUAGE "cancel" 0 +2
		Abort
FunctionEnd
