/* QTagConvert - Editor tags in mp3 files. Designed to convert codepage.
 * Copyright (C) 2007-2008 Skala <skala@users.sourceforge.net>
 * Copyright (C) 2009 Vasiliy Makarov <drmoriarty.0@gmail.com>
 *
 * This is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <QtGui>
#include "KCmp3Tag.h"
#include "aboutdialog.h"

mp3Dialog::mp3Dialog(QWidget *parent)
    : QMainWindow(parent)
{
    setupUi(this);

	QSettings *settings = new QSettings("Skala","QTagConvert");

	QStringList sl;
	foreach(QByteArray it, QTextCodec::availableCodecs ()) {
		sl << QString(it);
	}
	sl.sort();
	comboBox_codepage->addItems(sl);
	QString _codepage = settings->value("codepage", "System").toString();
	if(!_codepage.size()) _codepage = "System";
	comboBox_codepage->setCurrentIndex(comboBox_codepage->findText(_codepage));
	codepage = comboBox_codepage->currentText();

	comboBox_action->setCurrentIndex(settings->value("action", 0).toInt());
	action = settings->value("action", 0).toInt();

	dirslist = new QDirModel(this);
	treeDir->setModel(dirslist);
	//Give current path or from savesettings
	if (settings->value("currentPath","").toString()==""){//Нету установок
        treeDir->setRootIndex(dirslist->index(QDir::homePath()));
        comboPath->addItem(QDir::homePath(),QDir::homePath());
	} else {//Est
		//Add from settings
		comboPath->addItems(settings->value("filesPath","").toStringList());
		//Clear empty strings... I don't know how to clear them
		comboPath->removeItem(comboPath->findText(""));
		if (settings->value("SelectedPath","").toString()==""){
			treeDir->setRootIndex(dirslist->index(settings->value("currentPath","").toString()));
			comboPath->setCurrentIndex( comboPath->findText(settings->value("currentPath","").toString()) );
		} else {
			//Hotel tak, kak nizhe, no eto ne raspakovivaet papku
			//treeDir->setExpanded(dirslist->index(settings.value("SelectedPath","").toString()),true);
			treeDir->setRootIndex(dirslist->index(settings->value("SelectedPath","").toString()));
			//Go to selected path
			if (comboPath->findText(settings->value("SelectedPath","").toString())==-1)
				//If selectes path is not in combo-list, add them
				comboPath->addItem(settings->value("SelectedPath","").toString());
			comboPath->setCurrentIndex( comboPath->findText(settings->value("SelectedPath","").toString()) );
		}
	}
	treeDir->setColumnHidden(1,true);
	treeDir->setColumnHidden(2,true);
	treeDir->setColumnHidden(3,true);
	treeDir->setColumnHidden(4,true);
	dirslist->setSorting(QDir::DirsFirst|QDir::Name);
	dirslist->setFilter(QDir::Dirs|QDir::Files|QDir::Drives|QDir::NoDotAndDotDot);
	delete settings;
	statusBar()->showMessage(tr("Ready"), 3000);
}
void mp3Dialog::on_homeButton_clicked()
{
	setWaitCursor();
	treeDir->setRootIndex(dirslist->index(QDir::homePath()));
	comboPath->setCurrentIndex(comboPath->findText(QDir::homePath(),Qt::MatchExactly));
	QApplication::restoreOverrideCursor();
	setArrowCursor();
}

void mp3Dialog::on_upButton_clicked()
{
	setWaitCursor();
	//Щас... покурить надо, перед тем, как подняться вверхъ
	QDir *tempDir = new QDir(comboPath->currentText());
	tempDir->cdUp();
	treeDir->setRootIndex(dirslist->index(tempDir->path()));
	//Обеспечиваю неповторяемость
	int t = comboPath->findText(tempDir->path(),Qt::MatchExactly);
	if (t==-1){
        comboPath->addItem(tempDir->path(),tempDir->path());
		t = comboPath->findText(tempDir->path(),Qt::MatchExactly);
	};
	comboPath->setCurrentIndex(t);
	setArrowCursor();
	delete tempDir;
}

void mp3Dialog::on_comboPath_activated(int index)
{
	setWaitCursor();
	treeDir->setRootIndex(dirslist->index(comboPath->currentText()));
	setArrowCursor();
}

void mp3Dialog::closeEvent(QCloseEvent *event)
{

	QSettings *settings = new QSettings("Skala","QTagConvert");
	//Writteng in comboPath...
	int cp = comboPath->count();
	QStringList cpList;
	while (cp>-1){
        cpList << comboPath->itemText(cp);
		cp--;
	}
	settings->setValue("filesPath", cpList);
	//Writting CurrentPath
	settings->setValue("currentPath",comboPath->currentText());
	//Writting selectedPath (opened)
	if (dirslist->isDir(treeDir->rootIndex()))
		settings->setValue("SelectedPath",dirslist->filePath(treeDir->rootIndex()));
	else {//Если выбрал файл
		QFileInfo *tempFileInfo = new QFileInfo(dirslist->filePath(treeDir->rootIndex()));
		settings->setValue("SelectedPath",tempFileInfo->path());
		delete tempFileInfo;
	}
	settings->setValue("codepage", comboBox_codepage->currentText());
	settings->setValue("action", comboBox_action->currentIndex());

	delete settings;

	event->accept();//bye-bye
}
//chekForMP3 and connect to file
TagLib::MPEG::File* mp3Dialog::FileMP3Resolver (QString filepath)
{
	QFileInfo tempFileInfo = QFileInfo(filepath);
	if (tempFileInfo.suffix().toLower()=="mp3") {
		return new TagLib::MPEG::File(TagLib::FileName(QFile::encodeName(tempFileInfo.absoluteFilePath())));
	}
	return 0;
}
//When clicked on listfiles
void mp3Dialog::on_treeDir_activated(const QModelIndex & index)
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver(dirslist->filePath(index));
	//QTextCodec::setCodecForCStrings (QTextCodec::codecForName("System"));
	if (FileMP3!=0){//Если выбрал файл и он mp3
		if(FileMP3->ID3v1Tag()) {
			TagLib::String titlev1 = FileMP3->ID3v1Tag()->title();
			TagLib::String artistv1 = FileMP3->ID3v1Tag()->artist();
			TagLib::String albumv1 = FileMP3->ID3v1Tag()->album();
			TagLib::String commentv1 = FileMP3->ID3v1Tag()->comment();
			TagLib::String genrev1 = FileMP3->ID3v1Tag()->genre();
			lineEditnameV1->setText(TStringToQString(titlev1));
			lineEditGroupV1->setText(TStringToQString(artistv1));
			lineEditAlbum->setText(TStringToQString(albumv1));
			lineCommentV1->setText(TStringToQString(commentv1));
			lineEditYearV1->setText(QString::number(FileMP3->ID3v1Tag()->year()));
			QString QSgenre1 = TStringToQString(genrev1);
			if (!QSgenre1.isEmpty())
				comboGenreV1->setCurrentIndex( comboGenreV1->findText(QSgenre1) );
			// id3v1 конвертится автоматически из установленной кодировки
			ConvertText(lineEditnameV1);
			ConvertText(lineEditGroupV1);
			ConvertText(lineEditAlbum);
			ConvertText(lineCommentV1);
		}
		if (FileMP3->ID3v2Tag()){
			TagLib::String titlev2 = FileMP3->ID3v2Tag()->title();
			TagLib::String artistv2 = FileMP3->ID3v2Tag()->artist();
			TagLib::String albumv2 = FileMP3->ID3v2Tag()->album();
			TagLib::String commentv2 = FileMP3->ID3v2Tag()->comment();
			TagLib::String genrev2 = FileMP3->ID3v2Tag()->genre();
			lineEditnameV2->setText(TStringToQString(titlev2));
			lineEditGroupV2->setText(TStringToQString(artistv2));
			lineEditAlbumV2->setText(TStringToQString(albumv2));
			lineCommenV2->setText(TStringToQString(commentv2));
			lineEditYearV2->setText(QString::number(FileMP3->ID3v2Tag()->year()));
//Жанр...
			if (!genrev2.isNull())
				comboGenreV2->setCurrentIndex( comboGenreV2->findText(TStringToQString(genrev2)) );
		}
		delete FileMP3;
	}
}

void mp3Dialog::on_treeDir_clicked(const QModelIndex & index)
{
	setWaitCursor();
	//Очищаю линеедиты
	lineEditnameV1->setText("");
	lineEditGroupV1->setText("");
	lineEditAlbum->setText("");
	lineCommentV1->setText("");
	lineEditnameV2->setText("");
	lineEditGroupV2->setText("");
	lineEditAlbumV2->setText("");
	lineCommenV2->setText("");
	comboGenreV1->setCurrentIndex(0);
	comboGenreV2->setCurrentIndex(0);
	//А теперь- рисуем остальное
	on_treeDir_activated(index);
	setArrowCursor();
}

//Копировать тэги из v1 в v2
void mp3Dialog::on_v1tov2_clicked()
{
	//Естественно, берем из комбобокса (на хрена брать из тэга1,- вдруг его редактировали...)
	lineEditnameV2->setText(lineEditnameV1->text());
	lineEditGroupV2->setText(lineEditGroupV1->text());
	lineEditYearV2->setText(lineEditYearV1->text());
	lineCommenV2->setText(lineCommentV1->text());
	lineEditAlbumV2->setText(lineEditAlbum->text());
	comboGenreV2->setCurrentIndex(comboGenreV1->currentIndex());
}
//Копировать тэги из v2 в v1
void mp3Dialog::on_v2tov1_clicked()
{
	//Естественно, берем из комбобокса (на хрена брать из тэга1,- вдруг его редактировали...)
	lineEditnameV1->setText(lineEditnameV2->text());
	lineEditGroupV1->setText(lineEditGroupV2->text());
	lineEditYearV1->setText(lineEditYearV2->text());
	lineCommentV1->setText(lineCommenV2->text());
	lineEditAlbum->setText(lineEditAlbumV2->text());
	comboGenreV1->setCurrentIndex(comboGenreV2->currentIndex());
}


//Сохраняем тэги для 1го файла
void mp3Dialog::on_ButtonSaveTags_clicked()
{
	if(!lineEditnameV1->text().isEmpty()){
		//QByteArray NameCode = charChanged->itemData(charChanged->currentIndex()).toByteArray();
		TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
		if (FileMP3!=0){
			QTextCodec *codec = QTextCodec::codecForName("System");
			//А вот ниже строка не влияет ни на что. Нужна ли- хз... Но пусть будет. Так все советуют
			//QTextCodec::setCodecForCStrings (QTextCodec::codecForName("System"));
			TagLib::ID3v2::FrameFactory::instance()->setDefaultTextEncoding(TagLib::String::UTF8);
			if (FileMP3->ID3v1Tag(true)){
				FileMP3->ID3v1Tag()->setAlbum(TagLib::String(codec->fromUnicode(lineEditAlbum->text()).data(), TagLib::String::Latin1));
				FileMP3->ID3v1Tag()->setTitle(TagLib::String(codec->fromUnicode(lineEditnameV1->text()).data(), TagLib::String::Latin1));
				FileMP3->ID3v1Tag()->setArtist(TagLib::String(codec->fromUnicode(lineEditGroupV1->text()).data(), TagLib::String::Latin1));
				FileMP3->ID3v1Tag()->setYear(lineEditYearV1->text().toUInt());
				FileMP3->ID3v1Tag()->setComment(TagLib::String(codec->fromUnicode(lineCommentV1->text()).data(), TagLib::String::Latin1));
				FileMP3->ID3v1Tag()->setGenre(TagLib::String(codec->fromUnicode(comboGenreV1->currentText()).data(), TagLib::String::Latin1));
			}
			if (FileMP3->ID3v2Tag(true)){
				FileMP3->ID3v2Tag()->setAlbum(Q2StringToTString(lineEditAlbumV2->text()));
				FileMP3->ID3v2Tag()->setTitle(Q2StringToTString(lineEditnameV2->text()));
				FileMP3->ID3v2Tag()->setArtist(Q2StringToTString(lineEditGroupV2->text()));
				FileMP3->ID3v2Tag()->setYear(lineEditYearV2->text().toUInt());
				FileMP3->ID3v2Tag()->setComment(Q2StringToTString(lineCommenV2->text()));
				FileMP3->ID3v2Tag()->setGenre(Q2StringToTString(comboGenreV2->currentText()));
			}
			int tags = 0;
			if(checkBox_ID3v1->checkState()) tags |= TagLib::MPEG::File::ID3v1;
			if(checkBox_ID3v2->checkState()) tags |= TagLib::MPEG::File::ID3v2;
			FileMP3->save(tags);
			delete FileMP3;
		}
}
}

// сохранить для всех файлов в каталоге отмеченные теги из набора ID3v2
void mp3Dialog::on_SaveAllFiles_clicked()
{
	setWaitCursor();
	//QTextCodec::setCodecForCStrings (QTextCodec::codecForName("System"));
	TagLib::ID3v2::FrameFactory::instance()->setDefaultTextEncoding(TagLib::String::UTF8);
	if(!lineEditnameV2->text().isEmpty()){
		QFileInfo *tempFileInfo = new QFileInfo(dirslist->filePath(treeDir->currentIndex()));
		QDir *tempDir = new QDir (tempFileInfo->path()); 
		QStringList filters;
     	filters << "*.mp3" << "*.MP3" << "*.Mp3" << "mP3";
		tempDir->setNameFilters(filters);
		tempDir->setFilter(QDir::Files);
		QStringList fileNamesList = tempDir->entryList();
		QFileInfoList fileInfoList = tempDir->entryInfoList();
		int iFiles = fileInfoList.count();
		//Теперь нужно посмотреть, что там поотмечал юзер			
		//Готовимся к поступлению в институт
		TagLib::String allGroup = Q2StringToTString(lineEditGroupV2->text());
		TagLib::String allAlbum = Q2StringToTString(lineEditAlbumV2->text());
		TagLib::String allGenre = Q2StringToTString(comboGenreV2->currentText());
		TagLib::String allComment = Q2StringToTString(lineCommenV2->text());
		TagLib::uint allYear = lineEditYearV2->text().toUInt();

		for (int temp = 0;temp<iFiles;temp++){
			QFileInfo tempMP3 = fileInfoList.at(temp);//Взял файл
			statusBar()->showMessage(tempMP3.filePath()+" ("+QString::number(iFiles)+tr(" of ")+QString::number(iFiles)+")", 2000);//Вывел о нем инфу
			TagLib::MPEG::File *FileMP3 = FileMP3Resolver( tempMP3.filePath() ) ;
			if (FileMP3!=0){
				if (FileMP3->ID3v2Tag(true)){
					if (GroupAllFiles->checkState())
						FileMP3->ID3v2Tag(true)->setArtist(allGroup);
					if (AlbumAllfiles->checkState())
						FileMP3->ID3v2Tag(true)->setAlbum(allAlbum);
					if (GenreAllFiles->checkState())
						FileMP3->ID3v2Tag(true)->setGenre(allGenre);
					if (YearAllfiles->checkState())
						FileMP3->ID3v2Tag(true)->setYear(allYear);
					if (CommentAllFiles->checkState())
						FileMP3->ID3v2Tag(true)->setComment(allComment);
					FileMP3->save();
				}
				delete FileMP3;			
			}
		}
		delete tempDir;
		delete tempFileInfo;
	}
	setArrowCursor();
	statusBar()->showMessage(tr("Ready"), 2000);
}

void mp3Dialog::setWaitCursor()
{
	setCursor(Qt::WaitCursor);
	lineEditnameV1->setCursor(Qt::WaitCursor);
	lineEditGroupV1->setCursor(Qt::WaitCursor);
	lineEditAlbum->setCursor(Qt::WaitCursor);
	lineEditYearV1->setCursor(Qt::WaitCursor);
	lineCommentV1->setCursor(Qt::WaitCursor);
	lineEditnameV2->setCursor(Qt::WaitCursor);
	lineEditGroupV2->setCursor(Qt::WaitCursor);
	lineEditAlbumV2->setCursor(Qt::WaitCursor);
	lineEditYearV2->setCursor(Qt::WaitCursor);
	lineCommenV2->setCursor(Qt::WaitCursor);
	comboPath->setCursor(Qt::WaitCursor);
}

void mp3Dialog::setArrowCursor()
{
	setCursor(Qt::ArrowCursor);
	lineEditnameV1->setCursor(Qt::ArrowCursor);
	lineEditGroupV1->setCursor(Qt::ArrowCursor);
	lineEditAlbum->setCursor(Qt::ArrowCursor);
	lineEditYearV1->setCursor(Qt::ArrowCursor);
	lineCommentV1->setCursor(Qt::ArrowCursor);
	lineEditnameV2->setCursor(Qt::ArrowCursor);
	lineEditGroupV2->setCursor(Qt::ArrowCursor);
	lineEditAlbumV2->setCursor(Qt::ArrowCursor);
	lineEditYearV2->setCursor(Qt::ArrowCursor);
	lineCommenV2->setCursor(Qt::ArrowCursor);
	comboPath->setCursor(Qt::ArrowCursor);
}

// конвертить все файлы в каталоге
void mp3Dialog::on_CovertForAll_clicked()
{
	setWaitCursor();
	int tags = 0;
	if(checkBox_allID3v1->checkState()) tags |= TagLib::MPEG::File::ID3v1;
	if(checkBox_allID3v2->checkState()) tags |= TagLib::MPEG::File::ID3v2;
	QString newName1, newGroup1, newAlbum1, newComment1, newName2, newGroup2, newAlbum2, newComment2;
	TagLib::ID3v2::FrameFactory::instance()->setDefaultTextEncoding(TagLib::String::UTF8);
	//QTextCodec::setCodecForCStrings (QTextCodec::codecForName(NameCode));
	{
		QFileInfo *tempFileInfo = new QFileInfo(dirslist->filePath(treeDir->currentIndex()));
		QDir *tempDir = new QDir (tempFileInfo->path()); 
		//QDir::Files,QDir::Name|QDir::IgnoreCase,!QDir::Hidden && !QDir::System);
		QStringList filters;
     	filters << "*.mp3" << "*.MP3" << "*.Mp3" << "mP3";
		tempDir->setNameFilters(filters);
		tempDir->setFilter(QDir::Files);
		QStringList fileNamesList = tempDir->entryList();
		QFileInfoList fileInfoList = tempDir->entryInfoList();
		int iFiles = fileInfoList.count();
		for (int temp = 0;temp<iFiles;temp++){
			QFileInfo tempMP3 = fileInfoList.at(temp);//Взял файл
			statusBar()->showMessage(tempMP3.filePath()+" ("+QString::number(iFiles)+tr(" of ")+QString::number(iFiles)+")", 2000);//Вывел о нем инфу
			TagLib::MPEG::File *FileMP3 = FileMP3Resolver( tempMP3.filePath() ) ;
			if (FileMP3!=0){
				if(FileMP3->ID3v1Tag()) {
					newName1 = Convert(TStringToQString(FileMP3->ID3v1Tag()->title()));
					newGroup1 = Convert(TStringToQString(FileMP3->ID3v1Tag()->artist()));
					newComment1 = Convert(TStringToQString(FileMP3->ID3v1Tag()->comment()));
					newAlbum1 = Convert(TStringToQString(FileMP3->ID3v1Tag()->album()));
					
				}
				if(FileMP3->ID3v2Tag()) {
					newName2 = Convert(TStringToQString(FileMP3->ID3v2Tag()->title()));
					newGroup2 = Convert(TStringToQString(FileMP3->ID3v2Tag()->artist()));
					newComment2 = Convert(TStringToQString(FileMP3->ID3v2Tag()->comment()));
					newAlbum2 = Convert(TStringToQString(FileMP3->ID3v2Tag()->album()));
				}
				if(tags | TagLib::MPEG::File::ID3v1) {
					if(!newName1.size()) newName1 = newName2;
					if(!newGroup1.size()) newGroup1 = newGroup2;
					if(!newComment1.size()) newComment1 = newComment2;
					if(!newAlbum1.size()) newAlbum1 = newAlbum2;
					QTextCodec *codec = QTextCodec::codecForName("System");
					FileMP3->ID3v1Tag(true);
					FileMP3->ID3v1Tag()->setAlbum(TagLib::String(codec->fromUnicode(newAlbum1).data(), TagLib::String::Latin1));
					FileMP3->ID3v1Tag()->setTitle(TagLib::String(codec->fromUnicode(newName1).data(), TagLib::String::Latin1));
					FileMP3->ID3v1Tag()->setArtist(TagLib::String(codec->fromUnicode(newGroup1).data(), TagLib::String::Latin1));
					FileMP3->ID3v1Tag()->setComment(TagLib::String(codec->fromUnicode(newComment1).data(), TagLib::String::Latin1));
				}
				if(tags | TagLib::MPEG::File::ID3v2) {
					if(!newName2.size()) newName2 = newName1;
					if(!newGroup2.size()) newGroup2 = newGroup1;
					if(!newComment2.size()) newComment2 = newComment1;
					if(!newAlbum2.size()) newAlbum2 = newAlbum1;
					FileMP3->ID3v2Tag(true);
					FileMP3->ID3v2Tag()->setAlbum(Q2StringToTString(newAlbum2));
					FileMP3->ID3v2Tag()->setTitle(Q2StringToTString(newName2));
					FileMP3->ID3v2Tag()->setArtist(Q2StringToTString(newGroup2));
					FileMP3->ID3v2Tag()->setComment(Q2StringToTString(newComment2));
				}
				FileMP3->save();
				delete FileMP3;			
			}
		}
		delete tempDir;
		delete tempFileInfo;
	}

	setArrowCursor();
	statusBar()->showMessage(tr("Ready"), 2000);
}

void mp3Dialog::ConvertText(QLineEdit* edit)
{
	edit->setText(Convert(edit->text()));
}

QString mp3Dialog::Convert(QString text)
{
	switch(action) {
	case 0: // convert
		{
			if(codepage.size()) {
				QTextCodec *codec = QTextCodec::codecForName(codepage.toLocal8Bit());
				return codec->toUnicode(text.toAscii());
			}
		}
		break;
	case 1: // broken unicode
		{
			QString str = text;
			bool latin = false;
			bool local8bit = false;
			foreach(QChar ch, str) {
				ushort cc = ch.unicode(); 
				if(cc < 0x20) local8bit = true;
				if(cc >= 0x50) latin = true;
			}
			if(local8bit || !latin) {
				QTextCodec *codec = QTextCodec::codecForName("CP 1251");
				QString s;
				foreach(QChar c, str) {
					char buf;
					if((char)c.unicode() != 0x20) buf = (char)c.unicode() + 0xb0;
					else buf = 0x20;
					//s.append(QString::fromLocal8Bit(&buf, 1));
					s.append(codec->toUnicode(&buf, 1));
				}
				return s;
			}
		}
		break;
	}
	return text;
}

void mp3Dialog::setAction(int a)
{
	action = a;
	switch (a) {
	case 0:
		comboBox_codepage->setDisabled(false);
		break;
	case 1:
	default:
		comboBox_codepage->setDisabled(true);
		break;
	}
}

void mp3Dialog::setCodepage(QString cp)
{
	codepage = cp;
}

void mp3Dialog::doTitle1()
{
	ConvertText(lineEditnameV1);
}

void mp3Dialog::doArtist1()
{
	ConvertText(lineEditGroupV1);
}

void mp3Dialog::doAlbum1()
{
	ConvertText(lineEditAlbum);
}

void mp3Dialog::doComment1()
{
	ConvertText(lineCommentV1);
}

void mp3Dialog::reloadTitle1()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v1Tag()) {
		TagLib::String titlev1 = FileMP3->ID3v1Tag()->title();
		lineEditnameV1->setText(TStringToQString(titlev1));
	}
}

void mp3Dialog::reloadArtist1()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v1Tag()) {
		TagLib::String artistv1 = FileMP3->ID3v1Tag()->artist();
		lineEditGroupV1->setText(TStringToQString(artistv1));
	}
}

void mp3Dialog::reloadAlbum1()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v1Tag()) {
		TagLib::String albumv1 = FileMP3->ID3v1Tag()->album();
		lineEditAlbum->setText(TStringToQString(albumv1));
	}
}

void mp3Dialog::reloadComment1()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v1Tag()) {
		TagLib::String commentv1 = FileMP3->ID3v1Tag()->comment();
		lineCommentV1->setText(TStringToQString(commentv1));
	}
}


void mp3Dialog::doTitle2()
{
	ConvertText(lineEditnameV2);
}

void mp3Dialog::doArtist2()
{
	ConvertText(lineEditGroupV2);
}

void mp3Dialog::doAlbum2()
{
	ConvertText(lineEditAlbumV2);
}

void mp3Dialog::doComment2()
{
	ConvertText(lineCommenV2);
}

void mp3Dialog::reloadTitle2()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v2Tag()) {
		TagLib::String titlev2 = FileMP3->ID3v2Tag()->title();
		lineEditnameV2->setText(TStringToQString(titlev2));
	}
}

void mp3Dialog::reloadArtist2()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v2Tag()) {
		TagLib::String artistv2 = FileMP3->ID3v2Tag()->artist();
		lineEditGroupV2->setText(TStringToQString(artistv2));
	}
}

void mp3Dialog::reloadAlbum2()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v2Tag()) {
		TagLib::String albumv2 = FileMP3->ID3v2Tag()->album();
		lineEditAlbumV2->setText(TStringToQString(albumv2));
	}
}

void mp3Dialog::reloadComment2()
{
	TagLib::MPEG::File *FileMP3 = FileMP3Resolver( dirslist->filePath( treeDir->currentIndex () ) ) ;
	if (FileMP3 && FileMP3->ID3v2Tag()) {
		TagLib::String commentv2 = FileMP3->ID3v2Tag()->comment();
		lineCommenV2->setText(TStringToQString(commentv2));
	} else {
		lineCommenV2->setText("");
	}
}

void mp3Dialog::on_AboutMenu()
{
	AboutDialog ad(this);
	ad.exec();
}

void mp3Dialog::on_AboutQtMenu()
{
	QApplication::aboutQt();
}
